pub enum QuerySpec<'a> {
Bounds(&'a str),
Exists(&'a str),
ChildCount(&'a str),
}Expand description
What to query about a tagged widget.
Variants
Bounds(&'a str)
Get bounds of the widget with the given tag.
Exists(&'a str)
Check if a tagged widget exists in the tree.
ChildCount(&'a str)
Count children of the tagged widget.